==> certmanager-model-v1alpha3-6.0.0-sources.jar: io/fabric8/certmanager/api/model/v1alpha3/IssuerConditionBuilder.java <==
package io.fabric8.certmanager.api.model.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class IssuerConditionBuilder extends IssuerConditionFluentImpl<IssuerConditionBuilder> implements VisitableBuilder<IssuerCondition,IssuerConditionBuilder>{
  public IssuerConditionBuilder() {
    this(false);
  }
  public IssuerConditionBuilder(Boolean validationEnabled) {
    this(new IssuerCondition(), validationEnabled);
  }
  public IssuerConditionBuilder(IssuerConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public IssuerConditionBuilder(IssuerConditionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new IssuerCondition(), validationEnabled);
  }
  public IssuerConditionBuilder(IssuerConditionFluent<?> fluent,IssuerCondition instance) {
    this(fluent, instance, false);
  }
  public IssuerConditionBuilder(IssuerConditionFluent<?> fluent,IssuerCondition instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLastTransitionTime(instance.getLastTransitionTime()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withReason(instance.getReason()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  public IssuerConditionBuilder(IssuerCondition instance) {
    this(instance,false);
  }
  public IssuerConditionBuilder(IssuerCondition instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withLastTransitionTime(instance.getLastTransitionTime()); 
    this.withMessage(instance.getMessage()); 
    this.withReason(instance.getReason()); 
    this.withStatus(instance.getStatus()); 
    this.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  IssuerConditionFluent<?> fluent;
  Boolean validationEnabled;
  public IssuerCondition build() {
    IssuerCondition buildable = new IssuerCondition(fluent.getLastTransitionTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    return buildable;
  }
  
}

==> certmanager-model-v1alpha3-6.3.0-sources.jar: io/fabric8/certmanager/api/model/v1alpha3/IssuerConditionBuilder.java <==
package io.fabric8.certmanager.api.model.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class IssuerConditionBuilder extends IssuerConditionFluentImpl<IssuerConditionBuilder> implements VisitableBuilder<IssuerCondition,IssuerConditionBuilder>{
  public IssuerConditionBuilder() {
    this(false);
  }
  public IssuerConditionBuilder(Boolean validationEnabled) {
    this(new IssuerCondition(), validationEnabled);
  }
  public IssuerConditionBuilder(IssuerConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public IssuerConditionBuilder(IssuerConditionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new IssuerCondition(), validationEnabled);
  }
  public IssuerConditionBuilder(IssuerConditionFluent<?> fluent,IssuerCondition instance) {
    this(fluent, instance, false);
  }
  public IssuerConditionBuilder(IssuerConditionFluent<?> fluent,IssuerCondition instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLastTransitionTime(instance.getLastTransitionTime()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withObservedGeneration(instance.getObservedGeneration()); 
    fluent.withReason(instance.getReason()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  public IssuerConditionBuilder(IssuerCondition instance) {
    this(instance,false);
  }
  public IssuerConditionBuilder(IssuerCondition instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withLastTransitionTime(instance.getLastTransitionTime()); 
    this.withMessage(instance.getMessage()); 
    this.withObservedGeneration(instance.getObservedGeneration()); 
    this.withReason(instance.getReason()); 
    this.withStatus(instance.getStatus()); 
    this.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  IssuerConditionFluent<?> fluent;
  Boolean validationEnabled;
  public IssuerCondition build() {
    IssuerCondition buildable = new IssuerCondition(fluent.getLastTransitionTime(),fluent.getMessage(),fluent.getObservedGeneration(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    return buildable;
  }
  
}
